'use client'
import React, { useState } from "react";
import { useFormik } from "formik";
// internal
import { Email, EyeCut, Lock, UserThree } from "@/svg";
import { register_schema } from "@utils/validation-schema";
import ErrorMsg from "./error-msg";
import { ToastContainer, toast } from 'react-toastify';
const RegisterForm = () => {
  const [showPass, setShowPass] = useState(false);
  const [showConPass, setShowConPass] = useState(false);
  // use formik

  const { handleChange, handleSubmit, handleBlur, errors, values, touched } =
    useFormik({
      initialValues: {
        firstName: "",
        lastName: "",
        email: "",
        phone: "",
        country: "",
        city: "",
        district: "",
        address: "",
        password: "",
        passwordConfirmation: "",
      },
      validationSchema: register_schema,
      onSubmit: async (values, { resetForm }) => {
        try {
          await fetch(process.env.API_LOCAL + "/sanctum/csrf-cookie", {
            method: "GET",
            credentials: "include",
          });
          const response = await fetch(process.env.API_LOCAL + "/users", {
            method: "POST",
            headers: {
              'X-CSRF-TOKEN': getCookie('XSRF-TOKEN'),
              "Content-Type": "application/json",
            },
            withCredentials: true,
            mode: 'cors',
            body: JSON.stringify(values),
          });

          if (!response.ok) {

            console.log("Form submit failed:", response);
          }

          const result = await response.json();
          console.log("Form submitted successfully:", result);

          resetForm();
        } catch (error) {
          console.error("Error submitting form:", error);
        }
      },

    });
  function getCookie(name) {
    let match = document.cookie.match(new RegExp('(^| )' + name + '=([^;]+)'));
    return match ? match[2] : '';
  }
  return (
    <form onSubmit={handleSubmit}>
      <div className="login__input-wrapper">
        <div className=" d-flex flex-column flex-md-row justify-content-between mb-3 mb-md-0 ">

          <div className="login__input-item">
            <div className="login__input">
              <input
                name="firstName"
                value={values.firstName}
                onChange={handleChange}
                onBlur={handleBlur}
                type="text"
                placeholder="Adınızı Giriniz"
                id="firstName"
                required
              />
            </div>
          </div>
          <div className="login__input-item">
            <div className="login__input">
              <input
                name="lastName"
                value={values.lastName}
                onChange={handleChange}
                onBlur={handleBlur}
                type="text"
                placeholder="Soyadınızı Giriniz"
                id="lastName"
                required
              />
            </div>
          </div>

        </div>
        <div className=" d-flex flex-column flex-md-row justify-content-between mb-3 mb-md-0">
          <div className="login__input-item">
            <div className="login__input">
              <input
                name="email"
                value={values.email}
                onChange={handleChange}
                onBlur={handleBlur}
                type="email"
                placeholder="E Posta"
                id="email"
                required
              />
            </div>
          </div>
          <div className="login__input-item">
            <div className="login__input">
              <input
                name="phone"
                value={values.phone}
                onChange={handleChange}
                onBlur={handleBlur}
                type="tel"
                placeholder="Telefon"
                id="phone"
                required
              />
            </div>
          </div>
        </div>
        <div className="login__input-item">
          <div className="login__input">
            <input
              name="country"
              value={values.country}
              onChange={handleChange}
              onBlur={handleBlur}
              type="text"
              placeholder="Ülke"
              id="country"
              required
            />
          </div>
        </div>

        <div className="login__input-item">
          <div className="login__input">
            <input
              name="district"
              value={values.district}
              onChange={handleChange}
              onBlur={handleBlur}
              type="text"
              placeholder="District"
              id="district"
              required
            />
          </div>
        </div>
        <div className="login__input-item">
          <div className="login__input">
            <input
              name="city"
              value={values.city}
              onChange={handleChange}
              onBlur={handleBlur}
              type="text"
              placeholder="Bölge / Eyalet"
              id="city"
              required
            />
          </div>
        </div>

        <div className="login__input-item">
          <div className="login__input">
            <input
              name="address"
              value={values.address}
              onChange={handleChange}
              onBlur={handleBlur}
              type="text"
              placeholder="Adres"
              id="address"
              required
            />
          </div>
        </div>
        <div className=" d-flex flex-column flex-md-row justify-content-between mb-3 mb-md-0">
          <div className="login__input-item">
            <div className="login__input-item-inner p-relative">
              <div className="login__input">
                <input
                  name="password"
                  value={values.password}
                  onChange={handleChange}
                  onBlur={handleBlur}
                  type={showPass ? "text" : "password"}
                  placeholder="Şifreniz"
                  id="password"
                  required
                />
                <span>
                  <Lock />
                </span>
              </div>
              <span
                className="login-input-eye"
                onClick={() => setShowPass(!showPass)}
              >
                {showPass ? <i className="fa-regular fa-eye"></i> : <EyeCut />}
              </span>
            </div>
            {touched.password && <ErrorMsg error={errors.password} />}
          </div>

          <div className="login__input-item">
            <div className="login__input-item-inner p-relative">
              <div className="login__input">
                <input
                  name="passwordConfirmation"
                  value={values.passwordConfirmation}
                  onChange={handleChange}
                  onBlur={handleBlur}
                  type={showConPass ? "text" : "password"}
                  placeholder="Şifrenizi Tekrar Giriniz"
                  id="passwordConfirmation"
                  required
                />
                <span>
                  <Lock />
                </span>
              </div>
              <span
                className="login-input-eye"
                onClick={() => setShowConPass(!showConPass)}
              >
                {showConPass ? <i className="fa-regular fa-eye"></i> : <EyeCut />}
              </span>
            </div>
            {touched.passwordConfirmation && (
              <ErrorMsg error={errors.passwordConfirmation} />
            )}
          </div>
        </div>
      </div>
      <div className="login__btn">
        <button type="submit" className="tp-btn-blue-sm w-100">
          Kayıt Ol
        </button>
      </div>
    </form>
  );
};

export default RegisterForm;
