import { usePathname, useRouter } from 'next/navigation';
import { useState, useEffect, useRef } from 'react';

const LanguageSwitch = ({ locale }) => {
  const pathname = usePathname();
  const router = useRouter();
  const [currentPath, setCurrentPath] = useState(pathname);
  const [isOpen, setIsOpen] = useState(false);
  const dropdownRef = useRef(null); // Dropdown menüyü referansla

  useEffect(() => {
    setCurrentPath(pathname); // Yol değiştiğinde güncelle
  }, [pathname]);

  useEffect(() => {
    const handleClickOutside = (event) => {
      if (dropdownRef.current && !dropdownRef.current.contains(event.target)) {
        setIsOpen(false); // Dropdown'u kapat
      }
    };

    // Event listener ekle
    document.addEventListener('mousedown', handleClickOutside);

    // Temizle
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, []);
  async function switchLocale(newLocale) {
    const newPath = currentPath.replace(`/${locale}`, `/${newLocale}`);
    try {
      const apiUrl = process.env.NEXT_PUBLIC_API_LOCAL_8000 + "/api/set-language/" + newLocale;
      console.log("API URL:", apiUrl);
      let response = await fetch(apiUrl, {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },

      });
      if (!response.ok) {
        throw new Error(`HTTP error! status: ${response.status}`);
      }


      // Yanıtın JSON formatında olduğunu varsayalım
      const data = await response.json();
      console.log("Response data:", data);

      router.replace(newPath); // Sayfayı yeniden yüklemeden değiştirme
      setIsOpen(false); // Dropdown'u kapat

    } catch (error) {
      console.error("Failed to set locale:", error);
    }
   
  };

  return (
    <div className="footerThree" ref={dropdownRef}>
      <button
        className="toggleButton"
        onClick={() => setIsOpen(!isOpen)}
      >
        {locale === "en" ? "🇬🇧 EN" : "🇹🇷 TR"}
      </button>

      <div className={`dropdownMenu ${isOpen ? "open" : ''}`}>
        <div
          className="dropdownItem"
          onClick={() => switchLocale("en")}
        >
         🇬🇧 EN
        </div>
        <div
          className="dropdownItem"
          onClick={() => switchLocale("tr")}
        >
         🇹🇷 TR
        </div>
      </div>
    </div>
  );
};

export default LanguageSwitch;