import React from "react";
import Link from "next/link";
import { NextArrowTwo, PrevArrowTwo } from "@/svg";

const Pagination = ({ currentPage, lastPage }) => {
  if (!lastPage || lastPage < 2) return null;
  const getPageNumbers = () => {
    const pages = [];
    for (let i = 1; i <= lastPage; i++) {
      if (i === 1 || i === lastPage || (i >= currentPage - 2 && i <= currentPage + 2)) {
        pages.push(i);
      } else if (pages[pages.length - 1] !== "...") {
        pages.push("...");
      }
    }
    return pages;
  };
  return (
    <nav>
      <ul className="flex gap-2">
        {/* Previous Button */}
        {currentPage > 1 ? (
          <li>
            <Link href={`${currentPage - 1}`} className="tp-pagination-prev prev page-numbers">
              <PrevArrowTwo /> Prev
            </Link>
          </li>
        ) : (
          <li>
            <span className="tp-pagination-prev prev page-numbers opacity-50 cursor-not-allowed" style={{ paddingRight: "15px" , paddingLeft: "15px"}}>
              <PrevArrowTwo /> Prev
            </span>
          </li>
        )}

        {/* Page Numbers */}
        {getPageNumbers().map((page, index) => (
          <li key={index}>
            {page === "..." ? (
              <span className="page-numbers">{page}</span>
            ) : currentPage === page ? (
              <span className="current page-numbers">{page}</span>
            ) : (
              <Link href={`${page}`} className="page-numbers">
                {page}
              </Link>
            )}
          </li>
        ))}

        {/* Next Button */}
        {currentPage < lastPage ? (
          <li>
            <Link href={`${currentPage + 1}`} className="next page-numbers">
              Next <NextArrowTwo />
            </Link>
          </li>
        ) : (
          <li>
            <span className="next page-numbers opacity-50 cursor-not-allowed" style={{ paddingRight: "15px" , paddingLeft: "15px"}}>
              Next <NextArrowTwo />
            </span>
          </li>
        )}
      </ul>
    </nav>
  );
};

export default Pagination;
